/*
PovWip

A program for automatically archiving "in progress"
snapshots of PovRay images.

I hereby place this program in the public domain.
You are free to do absolutely whatever you want
with it. Have fun!
*/

import java.awt.*;
import java.awt.image.*;
import java.io.*;
import javax.imageio.*;

public class PovWip {
  public static final int  WIDTH = 320;
  public static final int HEIGHT = 240;

  public static void main(String args[]) {
    System.out.print("POVWIP executing...");
    if (args.length == 0) {
      System.err.println("failed.");
      System.err.println("No filename given!");
      System.exit(1);
    } else if (args.length > 1) {
      System.err.println("failed.");
      System.err.println("Too many arguments!");
      System.exit(1);
    }
    
    String filename = args[0];
    BufferedImage image;
    BufferedImage outimage;
    File infile = new File(filename);
    String basename = infile.getName().split("\\.")[0];
    File folder = new File(basename);
    int existing;
    StringBuffer outname = new StringBuffer(basename);
    File outfile;
    boolean success;

    try {
      image = ImageIO.read(infile);
  
      if (!folder.exists())
        folder.mkdir();
      
      existing = folder.listFiles().length;
      for (int place = 1000; place > 0; place/=10) {
        int digit = existing / place;
        outname.append(digit);
        existing %= place;
      }
      outname.append(".jpg");

      outimage = new BufferedImage(WIDTH, HEIGHT, BufferedImage.TYPE_INT_RGB);
      Graphics2D g2d = outimage.createGraphics();
      g2d.setColor(Color.BLACK);
      g2d.fillRect(0, 0, WIDTH, HEIGHT);
      g2d.setRenderingHint(RenderingHints.KEY_INTERPOLATION,
                          RenderingHints.VALUE_INTERPOLATION_BILINEAR);
      
      if (image.getHeight() == image.getWidth() * 3 / 4) {
        /* No bars */
        g2d.drawImage(image, 0, 0, WIDTH, HEIGHT, null);
      } else if (image.getHeight() > image.getWidth() * 3 / 4) {
        /* vertical bars */
        /* new height = HEIGHT; y = 0 */
        /* new width = width * HEIGHT / height; x = (WIDTH - new width) / 2 */
        int width = image.getWidth() * HEIGHT / image.getHeight();

        g2d.drawImage(image, (WIDTH - width) / 2, 0, width, HEIGHT, null);
      } else {
        /* horizontal bars */
        /* new height = height * WIDTH  / width; y = (HEIGHT - new height) / 2 */
        /* new width = WIDTH; x = 0 */
        int height = image.getHeight() * WIDTH / image.getWidth();

        g2d.drawImage(image, 0, (HEIGHT - height) / 2, WIDTH, height, null);
      }

      outfile = new File(folder, outname.toString());
      success = ImageIO.write(outimage, "jpeg", outfile);

      if (success) {
        System.out.println("success!");
      } else {
        System.out.println("failed. No writer for jpeg found.");
      }
    } catch (IOException e) {
      System.out.println("failed.");
      System.out.println(e);
    }
  }
}